#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.1
id: warp-tls-3.2.1-1236b7efa520b28daaf1039664c2daee
key: warpt_LkGHrfh58oW9nQ9ulA4ObY
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    Support for SSL is now obsoleted.
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-tls-3.2.1
hs-libraries: HSwarp-tls-3.2.1-LkGHrfh58oW9nQ9ulA4ObY
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
    tls-1.3.8-96444b4e688bece54c4ea4192a68b9a3
    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
    warp-3.2.6-747ccbb2aaea6b63942f452bd0d269ae
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
